@@ -1092,13 +1092,20 @@ def readZetasizerNano(filename, NANOcoding="cp1257", NANOlocale=None):
 
     Returns
     -------
-    dataList
-        X,Y columns are
-         * correlation data [CorrelationDelayTimes,sign(CorrData)*|CorrelationData|**0.5, CorrelationData] if present
-         * or RelaxationTimes, Sizes, Intensities, Volumes, Diffusions if present
-        If no correlation or sizes the data are zero and only parameters are stored.
+    dataList with dataArray for each measurement
+     Dataarray contains :
+       - correlation data [CorrelationDelayTime; g2minus1; g1] (if present otherwise empty dataArray)
+       - .distributions : Distribution fits with columns
+          [RelaxationTimes, Sizes, Intensities, Volumes, Diffusions] (if present)
+       - fit results of correlation function in attributes (some channels are discarded -> see Zetasizer settings)
+           - .distributionFitDelayTimes timechanels
+           - .distributionFitData measured points
+           - .distributionFit fit result
+       - Check .attr for more attributes like
+         SampleName, MeanCountRate, SizePeak1mean, SizePeak1width, Temperature
+
+        If no correlation or distributions are present the data are zero and only parameters are stored.
         No unit conversion is done.
-        Parameters contain any other information stored in line.
 
     CorrelationData.Y contains 1-g2=g1**2 with 0 for negative 1-g2.
 
@@ -1116,14 +1123,35 @@ def readZetasizerNano(filename, NANOcoding="cp1257", NANOlocale=None):
     --------
     ::
 
-    import jscatter as js
-    import numpy as np
-    import glob
-    files=glob.glob('../rawdata/PC4EG4/pc4eg4*.txt')
-    for file in files:
-        data=js.dls.readZetasizerNano(file)
-        p=js.grace()
-        p.plot(data) # plots correlation function
+     import jscatter as js
+     import numpy as np
+     # read example data
+     alldls = js.dls.readZetasizerNano(js.examples.datapath + '/dlsPolymerSolution.txt', NANOlocale=['de_DE', 'UTF-8'])
+     one=alldls[5]
+     p=js.grace()
+     p.multi(2,1,vgap=0.2)
+     p[0].plot(one,legend='correlation data (all)')
+     p[0].plot(one.distributions.X, one.distributions.Y /  10 , li=1, legend='intensity weighted distribution (x0.1)')
+     p[0].plot(one.DistributionFitDelayTimes,one.DistributionFitData,sy=[1,0.2,4],le='fitted data')
+     p[0].plot(one.DistributionFitDelayTimes,one.DistributionFit,sy=0,li=[1,2,5])
+     p[1].plot(one.distributions[1], one.distributions[2] , li=1, legend='radius distribution intensity weighted')
+     p[1].plot(one.distributions._Sizes, one.distributions._Volumes, li=1, legend='radius distribution volume weighted')
+
+     p[0].xaxis(scale='l', label=r'correlation time / µs ', tick=[10, 9])
+     p[1].xaxis(scale='l', label=r'radius / nm ')
+     p[0].yaxis(label=r'g1 / probability ')
+     p[1].yaxis(label=r'probability ')
+     p[0].legend(x=1000,y=1.9)
+     p[1].legend(x=50,y=30)
+     p[0].title('Zetasizer data with distribution fit')
+     p[0].subtitle('Results from instrument software')
+     # p.save(js.examples.imagepath+'/Zetasizerexample.jpg',format='jpeg',size=[600,600]) #as jpg file
+
+    .. image:: ../../examples/images/Zetasizerexample.jpg
+         :width: 50 %
+         :align: center
+         :alt: Graceexample
+
 
     """
     if NANOlocale is None:
@@ -1206,7 +1234,7 @@ def readZetasizerNano(filename, NANOcoding="cp1257", NANOlocale=None):
                              XYeYeX=[0, 1]))
             del data['CorrelationDelayTimes']
             del data['CorrelationData']
-            output[-1].columnname = 'CorrelationDelayTimes; CorrelationData=g2-1'
+            output[-1].columnname = 'CorrelationDelayTime; g2minus1; g1'
         elif len(columnnames) > 0:
             output.append(dA(np.c_[[np.array(data[name], dtype=float) for name in columnnames]], XYeYeX=[0, 1]))
             output[-1].columnname = ''.join(['%s; ' % name for name in columnnames])
