@@ -556,7 +556,7 @@ class jspaperAxes(matplotlib.axes.Axes):
 
         """
         while len(self.lines):
-            _ = lines.pop()
+            _ = self.lines.pop()
         self.figure.show()
 
     def Text(self, string, x, y, **kwargs):
@@ -932,6 +932,7 @@ def surface(x, y, z, shape=None, levels=8, colorMap='jet', lineMap=None, alpha=0
         X, Y, Z = regrid(x, y, z, shape)
         if X is None or Z is None or Y is None:
             raise Exception('x,y,z seem not to be on regular grid.')
+
     cmap = matplotlib.cm.get_cmap(colorMap)
     try:
         lmap = matplotlib.cm.get_cmap(lineMap)
@@ -959,7 +960,7 @@ def surface(x, y, z, shape=None, levels=8, colorMap='jet', lineMap=None, alpha=0
     return fig
 
 
-def scatter3d(x, y=None, z=None, pointsize=3, color='k'):
+def scatter3d(x, y=None, z=None, pointsize=3, color='k', ax=None):
     """
     Scatter plot of x,y,z data points.
 
@@ -971,6 +972,8 @@ def scatter3d(x, y=None, z=None, pointsize=3, color='k'):
         Size of points
     color : string
         Colors for points
+    ax : axes, default None
+        Axes to plot inside. If None a new figure is created.
 
     Returns
     -------
@@ -994,9 +997,12 @@ def scatter3d(x, y=None, z=None, pointsize=3, color='k'):
             x, y, z = x.T
         except ValueError:
             x, y, z = x
+    if ax is None:
+        fig = figure()
+        ax = fig.add_subplot(1, 1, 1, projection='3d')
+    else:
+        fig = ax.figure
 
-    fig = figure()
-    ax = fig.add_subplot(111, projection='3d')
     sc = ax.scatter(x, y, z, s=pointsize, color=color)
     mi = np.min([x, y])
     ma = np.max([x, y])
@@ -1273,6 +1279,152 @@ def contourImage(x, y=None, z=None, levels=None, fontsize=10, colorMap='jet', sc
     return fig
 
 
+def contourOnCube(xy, yz=None, xz=None, shape=None, offset=None, levels=None, colorMap='jet', scale='norm',
+                                        block=False, linthresh=1, linscale=1, badcolor=None, ax=None):
+    """
+    Plot 3 2d contourf planes on surface of a cube.
+
+    Intended to show 3D perpendicular scattering planes together.
+
+    Parameters
+    ----------
+    xy,yz,xz : array 3xNM
+        2D data [x,y,z] with shape N*M = NM.
+        Each is ploted parallel to the plane mentioned in name.
+        regrid is used to reshape to dimension 3xNxM
+    shape : list 2x float
+        2D shape of the above arrays
+    offset : list 3x float, default 0,0,0
+        Position of the  xy,yz,xz planes in a 3D plot.
+    levels : int, None, sequence of values
+        Number of contour lines between min and max or sequence of specific values.
+    colorMap : string
+        Get a colormap instance from name.
+        Standard mpl colormap name (see showColors).
+    badcolor : float, color
+        Set the color for bad values (like masked pixel) values in an image.
+        Default is  bad values be transparent.
+        Color can be matplotlib color as 'k','b' or
+        float value in interval [0,1] of the chosen colorMap.
+        0 sets to minimum value, 1 to maximum value.
+    scale : 'log', 'symlog', default = 'norm'
+        Scale for intensities.
+
+        - 'norm' Linear scale.
+        - 'log' Logarithmic scale
+        - 'symlog' Symmetrical logarithmic scale is logarithmic in both the positive
+          and negative directions from the origin. This works also for only positive data.
+          Use linthresh, linscale to adjust.
+    linthresh : float, default = 1
+        Only used for scale 'sym'.
+        The range within which the plot is linear (-linthresh to linthresh).
+    linscale : float, default = 1
+        Only used for scale 'sym'.
+        Its value is the number of decades to use for each half of the linear range.
+        E.g. 10 uses 1 decade.
+    block : bool
+        Open in blocking or non-blocking mode
+
+    Returns
+    -------
+        axes
+
+
+    Examples
+    --------
+    ::
+
+     import jscatter as js
+     import numpy as np
+
+     # detector planes; a real flat detector has z>0
+     q = np.mgrid[-9:9:51j, -9:9:51j].reshape(2,-1).T
+     grid= js.sf.scLattice(10/20,20).XYZ
+     fa = js.cloudscattering.fa_cuboid(*grid[:,:3].T,0.2,0.4,2)
+
+     rod0=np.array([[0,0,0,1,0,0]])
+     qz=np.c_[q,np.zeros_like(q[:,0])]  # for z=0
+     qy=np.c_[q[:,:1],np.zeros_like(q[:,0]),q[:,1:]]  # for z=0
+     qx=np.c_[np.zeros_like(q[:,0]),q]  # for z=0
+
+     ffz1 = js.ff.orientedCloudScattering3Dff(qz,cloud=rod0, formfactoramp=fa)
+     ffy1 = js.ff.orientedCloudScattering3Dff(qy,cloud=rod0, formfactoramp=fa)
+     ffx1 = js.ff.orientedCloudScattering3Dff(qx,cloud=rod0, formfactoramp=fa)
+
+     # show as cube surfaces
+     ax=js.mpl.contourOnCube(ffz1[[0,1,3]].array,ffx1[[1,2,3]].array,ffy1[[0,2,3]].array,offset=[-9,-9,9])
+     #ax.figure.savefig(js.examples.imagepath+'/contourOnCube.jpg')
+
+    .. image:: ../../examples/images/contourOnCube.jpg
+     :width: 50 %
+     :align: center
+     :alt: filledSphere
+
+
+
+    """
+    if ax is None:
+        fig = figure()
+        ax = fig.add_subplot(1, 1, 1, projection='3d')
+    else:
+        fig = ax.figure
+
+    # use copy so that we do not mutate the global colormap instance; stupid matplotlib programmers
+    cmap = copy.copy(matplotlib.cm.get_cmap(colorMap))
+    if badcolor is not None:
+        # set bad color
+        if isinstance(badcolor, numbers.Number):
+            cmap.set_bad(color=cmap(badcolor))
+        else:
+            cmap.set_bad(color=badcolor)
+    # try:
+    #     lmap = copy.copy(matplotlib.cm.get_cmap(lineMap))
+    # except ValueError:
+    #     lmap = lineMap
+
+    # determine the scaling (norm)
+    # determine vmin,vmax later
+    if scale[:3] == 'log':
+        norm = colors.LogNorm(clip=True)
+    elif scale[:3] == 'sym':
+        norm = colors.SymLogNorm(clip=True, linthresh=linthresh, linscale=linscale)
+    else:  # default: scale == 'normalize':
+        norm = colors.Normalize(clip=True)
+
+    if offset is None:
+        offset = 0
+    if isinstance(offset, numbers.Number):
+        offset=[offset]*3
+
+    minmax=[]
+    for xyz, zdir, off, o in zip([xy, yz, xz], ['z', 'x', 'y'], offset, [[0, 1, 2], [2, 0, 1], [0, 2, 1]]):
+        if xyz is None:
+            continue
+        minmax.append([np.min(xyz[0]), np.max(xyz[0])])
+        minmax.append([np.min(xyz[1]), np.max(xyz[1])])
+        XZY = regrid(xyz[0], xyz[1], xyz[2], shape)
+        if XZY[0] is None or XZY[1] is None or XZY[2] is None:
+            raise Exception('Some input seems not to be on regular grid.')
+        # determine vmax and vmin
+        norm.autoscale(XZY[2])
+        ax.contourf(XZY[o[0]], XZY[o[1]], XZY[o[2]],
+                    zdir=zdir, offset=off, cmap=colorMap, levels=levels, norm=norm)
+
+    minmax = np.array(minmax)
+    ax.tick_params(labelsize=8, pad=4)
+    ax.set_xlabel('X axis', fontsize='smaller')
+    ax.set_ylabel('Y axis', fontsize='smaller')
+    ax.set_zlabel('Z axis', fontsize='smaller')
+    ax.set_xlim(minmax[:, 0].min(), minmax[:, 1].max())
+    ax.set_ylim(minmax[:, 0].min(), minmax[:, 1].max())
+    ax.set_zlim(minmax[:, 0].min(), minmax[:, 1].max())
+    # fig.colorbar(surf, shrink=0.8)  # note that colorbar is a method of the figure, not the axes
+    # fig.tight_layout()
+
+    show(block=block)
+    return ax
+
+
 def showColors():
     """
     Get a list of the colormaps in matplotlib.
