@@ -103,8 +103,15 @@ class dataArrayTest(unittest.TestCase):
         # simulate data with error
         self.data = js.dA(np.c_[x, 1.234 * np.sin(x) + 0.001 * np.random.randn(len(x)), x * 0 + 0.001].T)
         self.data.amp = 1.234
-        self.data.fit(lambda x, A, a, B: A * np.sin(a * x) + B, {'a': 1.2, 'B': 0}, {}, {'x': 'X', 'A': 'amp'},
-                      output=False)
+
+        # fit without Error
+        self.data.fit(lambda x, A, a, B: A * np.sin(a * x) + B,
+                      {'a': 1.2, 'B': 0}, {}, {'x': 'X', 'A': 'amp'},
+                      method='Powell', output=False)
+        # refine error
+        self.data.estimateError(output=False)
+
+        # creation test...
         x1 = np.r_[0:100:]
         self.data2 = js.dA(np.c_[x1, x1 * 0 + 1., x1 * 0, x1 * 0].T)
         self.data2.test = 'dumdum'
@@ -112,6 +119,7 @@ class dataArrayTest(unittest.TestCase):
         self.data2.Y[2::4] = 4
         self.data2.Y[3::4] = 5
 
+        # read test
         with open('asciitestfile.dat', 'w') as f:    (f.write(asciitext))
         self.data4 = js.dA('asciitestfile.dat', replace={'#': '', ';': '', ',': '.'}, skiplines=['*', '**', 'nan'],
                            ignore='')
@@ -181,6 +189,7 @@ class dataArrayTest(unittest.TestCase):
         # self.assertEqual( self.data.X,self.x )
         self.assertTrue(np.alltrue(self.data.X == self.x))
         self.assertLess(abs(self.data.lastfit.A - self.data.amp), 0.01)
+        self.assertAlmostEqual(self.data.a_err, 2e-5, 5)
         self.assertLess(abs(self.data.B), 0.1)
         self.assertLess(abs(self.data.lastfit.chi2 - 1), 0.5)
 
@@ -478,8 +487,11 @@ class formelTest(unittest.TestCase):
         pQFGxD_g1 = js.formel.pQFGxD(gauss1, 0, 100, parnames='x', mean=50, sigma=10, q=q, n=15)
         pQFGxD_g3 = js.formel.pQFGxD(gauss3, [0, 0, 0], [100, 100, 100],
                                      parnames=['x', 'y', 'z'], mean=50, sigma=10, q=q, n=15)
+        pQACC_g3 = js.formel.pQACC(gauss3, [0, 0, 0], [100, 100, 100],
+                                     parnames=['x', 'y', 'z'], mean=50, sigma=10, q=q)[0]
         nptest.assert_array_almost_equal(pQFGxD_g1, q, 5)
         nptest.assert_array_almost_equal(pQFGxD_g3, q, 5)
+        nptest.assert_array_almost_equal(pQACC_g3, q, 5)
 
         # cubature on complex sphere formfactor
         R = 5
@@ -652,8 +664,8 @@ class sasTest(unittest.TestCase):
                 warnings.simplefilter("ignore")
                 # try if pymatgen is present
                 # noinspection PyPackageRequirements
-                import pymatgen
-                siliconcarbide = pymatgen.Structure.from_file(js.examples.datapath + '/1011053.cif')
+                import pymatgen.core
+                siliconcarbide = pymatgen.core.Structure.from_file(js.examples.datapath + '/1011053.cif')
                 self.sic = js.sf.latticeFromCIF(siliconcarbide)
                 agbe = js.sf.latticeFromCIF(js.examples.datapath + '/1507774.cif', size=[1, 1, 1])
                 self.lsf = js.sf.latticeStructureFactor(np.r_[0.9:1.3:0.01], lattice=agbe, domainsize=50,
@@ -786,6 +798,10 @@ class dynamicTest(unittest.TestCase):
         diff_w = js.dynamic.transDiff_w(w, q=qq, D=D)
         self.diff_cw = js.dynamic.convolve(diff_w, resolution, normB=1)
 
+        # test if ZilmanGranke is working for integration
+        self.iqt = js.dynamic.zilmanGranekLamellar(t=js.loglist(0.1, 30, 10), q=np.r_[0.1,0.2],
+                                                   df=100, kappa=1, eta=2*0.24e-3)
+
         self.setupdone = True
 
     def test_time2frequencyFF(self):
@@ -795,6 +811,9 @@ class dynamicTest(unittest.TestCase):
             (self.diff_ffw.interp(self.diff_cw.X[abs(X) < 70]) - self.diff_cw.Y[abs(X) < 70]) / self.diff_cw.Y[
                 abs(X) < 70]) < 0.025))
 
+    def test_ZGintegration(self):
+        nptest.assert_array_almost_equal(self.iqt[1].Y[2:], [0.970, 0.948, 0.914, 0.866, 0.803, 0.732, 0.666, 0.616],3)
+
 
 # noinspection PyMethodParameters,PyMethodParameters
 class plotTest(unittest.TestCase):
